Module lexer

Module lexer 

Lexer with layout insertion pass. Lexer producing a sequence of spanned tokens from source text.

Uses logos for fast regex-based tokenization, then applies a layout insertion pass to convert indentation into explicit Indent/Dedent/ Newline tokens (the GHC approach).

Structs

LexError
A lexer error with source location.

Functions

tokenize
Tokenize source text into a sequence of spanned tokens.